@@ -1,12 +1,9 @@
 import os
 import certifi
-import requests
 import logging
 
-from requests.exceptions import SSLError
 from pathlib import Path
 
-test_url = "https://design.dataiku.vestas.net/"
 certificate_dir = os.path.join(Path(__file__).parent, "certificates")
 
 
@@ -35,15 +32,19 @@ def add_certificates():
         f.writelines(certs)
 
 
+def has_certificates():
+    with open(certifi.where()) as f_bundle:
+        bundle = f_bundle.read()
+        for item in os.listdir(certificate_dir):
+            src = os.path.join(certificate_dir, item)
+            if item.endswith(".crt"):
+                with open(src) as cert:
+                    if cert.read() not in bundle:
+                        return False
+    return True
+
+
 def fix_ssl_error():
-    try:
-        r = requests.get(test_url)
-    except SSLError:
-        logging.info("Trying to fix SSL error.")
+    if not has_certificates():
+        logging.info("No Vestas certificates found - adding.")
         add_certificates()
-        # Check if the fix worked.
-        try:
-            r = requests.get(test_url)
-            logging.info("SSL fix worked.")
-        except SSLError:
-            logging.info("SSL fix failed.")
